==> mapmyindia_gl-0.2.0.tar.gz: lib/src/api/nearby/nearby_response.dart <==
part of mapmyindia_gl;

class NearbyResponse {
  List<NearbyResult>? suggestedLocations;
  PageInfo? pageInfo;

  static NearbyResponse fromMap(Map<String, dynamic> map) {
    NearbyResponse nearbyResponseBean = NearbyResponse();
    if (map.containsKey("suggestedLocations")) {
      List<dynamic> suggestedLocations =
          map['suggestedLocations'] as List<dynamic>;
      nearbyResponseBean.suggestedLocations =
          List.generate(suggestedLocations.length, (index) {
        return NearbyResult.fromMap(
            suggestedLocations[index] as Map<String, dynamic>);
      });
    }
    nearbyResponseBean.pageInfo = PageInfo.fromMap(map['pageInfo']);
    return nearbyResponseBean;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> map = <String, dynamic>{};

    void addIfNonNull(String fieldName, dynamic value) {
      if (value != null) {
        map[fieldName] = value;
      }
    }

    if (this.suggestedLocations != null) {
      map['suggestedLocations'] =
          List.generate(this.suggestedLocations!.length, (index) {
            return this.suggestedLocations![index].toJson();
          });
    }
    addIfNonNull('pageInfo', pageInfo?.toJson());
    return map;
  }
}

/// pageCount : 1
/// totalHits : 1
/// totalPages : 1
/// pageSize : 10
class PageInfo {
  int? pageCount;
  int? totalHits;
  int? totalPages;
  int? pageSize;

  static PageInfo fromMap(Map<String, dynamic> map) {
    PageInfo pageInfoBean = PageInfo();
    pageInfoBean.pageCount = map['pageCount'];
    pageInfoBean.totalHits = map['totalHits'];
    pageInfoBean.totalPages = map['totalPages'];
    pageInfoBean.pageSize = map['pageSize'];
    return pageInfoBean;
  }

  Map toJson() => {
        "pageCount": pageCount,
        "totalHits": totalHits,
        "totalPages": totalPages,
        "pageSize": pageSize,
      };
}


class NearbyResult {
  int? distance;
  String? eLoc;
  String? email;
  double? entryLatitude;
  double? entryLongitude;
  List<String>? keywords;
  String? landlineNo;
  double? latitude;
  double? longitude;
  String? mobileNo;
  int? orderIndex;
  String? placeAddress;
  String? placeName;
  String? type;
  String? categoryCode;
  String? hourOfOperation;
  AddressToken? addressTokens;
  Map? richInfo;

  static NearbyResult fromMap(Map<String, dynamic> map) {
    NearbyResult suggestedLocationsBean = NearbyResult();
    suggestedLocationsBean.distance = map['distance'];
    suggestedLocationsBean.eLoc = map['eLoc'];
    suggestedLocationsBean.email = map['email'];
    suggestedLocationsBean.entryLatitude = map['entryLatitude'];
    suggestedLocationsBean.entryLongitude = map['entryLongitude'];
    if(map.containsKey('keywords')) {
      List<dynamic> keywords = map['keywords'];
      suggestedLocationsBean.keywords = List.generate(keywords.length, (index) {
        return keywords[index] as String;
      });
    }
    suggestedLocationsBean.landlineNo = map['landlineNo'];
    suggestedLocationsBean.latitude = map['latitude'];
    suggestedLocationsBean.longitude = map['longitude'];
    suggestedLocationsBean.mobileNo = map['mobileNo'];
    suggestedLocationsBean.orderIndex = map['orderIndex'];
    suggestedLocationsBean.placeAddress = map['placeAddress'];
    suggestedLocationsBean.placeName = map['placeName'];
    suggestedLocationsBean.type = map['type'];
    suggestedLocationsBean.categoryCode = map['categoryCode'];
    suggestedLocationsBean.hourOfOperation = map['hourOfOperation'];
    suggestedLocationsBean.richInfo = map['richInfo'];
    if(map.containsKey('addressTokens')) {
      suggestedLocationsBean.addressTokens = AddressToken.fromMap(map['addressTokens']);
    }
    return suggestedLocationsBean;
  }

  Map toJson() => {
        "distance": distance,
        "eLoc": eLoc,
        "email": email,
        "entryLatitude": entryLatitude,
        "entryLongitude": entryLongitude,
        "keywords": keywords,
        "landlineNo": landlineNo,
        "latitude": latitude,
        "longitude": longitude,
        "mobileNo": mobileNo,
        "orderIndex": orderIndex,
        "placeAddress": placeAddress,
        "placeName": placeName,
        "type": type,
        "categoryCode": categoryCode,
        "hourOfOperation": hourOfOperation,
        "richInfo": richInfo,
        "addressTokens": addressTokens?.toJson(),
      };
}

==> mapmyindia_gl-0.2.1.tar.gz: lib/src/api/nearby/nearby_response.dart <==
part of mapmyindia_gl;

class NearbyResponse {
  List<NearbyResult>? suggestedLocations;
  PageInfo? pageInfo;

  static NearbyResponse fromMap(Map<String, dynamic> map) {
    NearbyResponse nearbyResponseBean = NearbyResponse();
    if (map.containsKey("suggestedLocations")) {
      List<dynamic> suggestedLocations =
          map['suggestedLocations'] as List<dynamic>;
      nearbyResponseBean.suggestedLocations =
          List.generate(suggestedLocations.length, (index) {
        return NearbyResult.fromMap(
            suggestedLocations[index] as Map<String, dynamic>);
      });
    }
    nearbyResponseBean.pageInfo = PageInfo.fromMap(map['pageInfo']);
    return nearbyResponseBean;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> map = <String, dynamic>{};

    void addIfNonNull(String fieldName, dynamic value) {
      if (value != null) {
        map[fieldName] = value;
      }
    }

    if (this.suggestedLocations != null) {
      map['suggestedLocations'] =
          List.generate(this.suggestedLocations!.length, (index) {
        return this.suggestedLocations![index].toJson();
      });
    }
    addIfNonNull('pageInfo', pageInfo?.toJson());
    return map;
  }
}

/// pageCount : 1
/// totalHits : 1
/// totalPages : 1
/// pageSize : 10
class PageInfo {
  int? pageCount;
  int? totalHits;
  int? totalPages;
  int? pageSize;

  static PageInfo fromMap(Map<String, dynamic> map) {
    PageInfo pageInfoBean = PageInfo();
    pageInfoBean.pageCount = map['pageCount'];
    pageInfoBean.totalHits = map['totalHits'];
    pageInfoBean.totalPages = map['totalPages'];
    pageInfoBean.pageSize = map['pageSize'];
    return pageInfoBean;
  }

  Map toJson() => {
        "pageCount": pageCount,
        "totalHits": totalHits,
        "totalPages": totalPages,
        "pageSize": pageSize,
      };
}

class NearbyResult {
  int? distance;
  String? eLoc;
  String? email;
  double? entryLatitude;
  double? entryLongitude;
  List<String>? keywords;
  String? landlineNo;
  double? latitude;
  double? longitude;
  String? mobileNo;
  int? orderIndex;
  String? placeAddress;
  String? placeName;
  String? type;
  String? categoryCode;
  String? hourOfOperation;
  AddressToken? addressTokens;
  Map? richInfo;

  static NearbyResult fromMap(Map<String, dynamic> map) {
    NearbyResult suggestedLocationsBean = NearbyResult();
    suggestedLocationsBean.distance = map['distance'];
    suggestedLocationsBean.eLoc = map['eLoc'];
    suggestedLocationsBean.email = map['email'];
    suggestedLocationsBean.entryLatitude = map['entryLatitude'];
    suggestedLocationsBean.entryLongitude = map['entryLongitude'];
    if (map.containsKey('keywords')) {
      List<dynamic> keywords = map['keywords'];
      suggestedLocationsBean.keywords = List.generate(keywords.length, (index) {
        return keywords[index] as String;
      });
    }
    suggestedLocationsBean.landlineNo = map['landlineNo'];
    suggestedLocationsBean.latitude = map['latitude'];
    suggestedLocationsBean.longitude = map['longitude'];
    suggestedLocationsBean.mobileNo = map['mobileNo'];
    suggestedLocationsBean.orderIndex = map['orderIndex'];
    suggestedLocationsBean.placeAddress = map['placeAddress'];
    suggestedLocationsBean.placeName = map['placeName'];
    suggestedLocationsBean.type = map['type'];
    suggestedLocationsBean.categoryCode = map['categoryCode'];
    suggestedLocationsBean.hourOfOperation = map['hourOfOperation'];
    suggestedLocationsBean.richInfo = map['richInfo'];
    if (map.containsKey('addressTokens')) {
      suggestedLocationsBean.addressTokens =
          AddressToken.fromMap(map['addressTokens']);
    }
    return suggestedLocationsBean;
  }

  Map toJson() => {
        "distance": distance,
        "eLoc": eLoc,
        "email": email,
        "entryLatitude": entryLatitude,
        "entryLongitude": entryLongitude,
        "keywords": keywords,
        "landlineNo": landlineNo,
        "latitude": latitude,
        "longitude": longitude,
        "mobileNo": mobileNo,
        "orderIndex": orderIndex,
        "placeAddress": placeAddress,
        "placeName": placeName,
        "type": type,
        "categoryCode": categoryCode,
        "hourOfOperation": hourOfOperation,
        "richInfo": richInfo,
        "addressTokens": addressTokens?.toJson(),
      };
}
